
# SETUP -------------

lapply(c("ggthemes","png","tidyverse","viridis","ggpubr","lubridate","ggpmisc","ggplot2","magick", "ggh4x","cowplot","stringr",
         "RColorBrewer","jpeg","grid","gridExtra","RCurl","rvest","stringi","extrafont","data.table","readxl","viridis","geomtextpath",
         "lsmeans","multcomp","lme4","merTools"),require,character.only=T)

setwd("C:/Users/roxan/Documents/Publications/Submitted/ROXANNE_Molt/Eseal Molt Final Data")
dat=read.csv("MoltMSFinal.csv")
dat=dat %>% 
  separate(X, c('Year', 'animalID')) #split year-animal into Year and AnimalID columns

mypalette=c("grey70", "#3F141F", "#E39AAD","grey20") 

figmain_palette <- c(
  "Juvenile Male" = mypalette[1],
  "Juvenile Female" = mypalette[2],
  "Repro Adult Female" = mypalette[3],
  "Skip Adult Female" = mypalette[4]
)

# Figure 2 (molt progress) ---------------------------------
#Graph logistic fit to molt progress along with molt observations for a single animal. 

#Color palette 

fig2_palette <- c(
  arrival = "#559B9D",
  start = "#235D72",
  end = "#A4DAC1",
  departure = "#123F5A"
)

out=read.csv("MoltMSFinalOut.csv")
modelout=read.csv("MoltMSFinalModelOut.csv")
annot=read.csv("MoltMSFinalAnnot.csv")
ay="2022-38369" 

f1=ggplot(data=out,aes(x=yday,y=molt))+
  annotate("text",
           x = annot$x-1.4,
           y = annot$y-.13,
           label = c("Arrival", "Molt Start","Molt End", "Departure"),
           color = fig2_palette,size=3,
           hjust = 0,vjust=0,angle=90) + 
  geom_vline(data=annot,aes(xintercept=x),size=3,alpha=.6,col=fig2_palette)+
  ggtitle(paste0("Adult Female Seal ",ay,"; Molt Duration = 7 days"))+
  geom_line(data=modelout,aes(x=graphx,y=pred1),col="grey10",linewidth=1)+
  geom_point(size=2,alpha=.9)+
  scale_y_continuous(labels = scales::percent,expand=c(.03,.03))+ 
  scale_x_continuous(expand=c(0,0))+
  scale_colour_manual(values = fig2_palette) +
  xlab("Date (day of year)")+ylab("Percent Molt")+theme_few()+
  theme(plot.margin = margin(10, 10, 10, 20),title = element_text(size=8))
f1

# add eseal images
# graphical parameters
# define plot layout 
lay <- rbind(c(2,1,1,1),
             c(3,1,1,1),
             c(4,1,1,1))

setwd("~/Publications/Submitted/ROXANNE_Molt/Eseal Molt Figures")
Img3 = rasterGrob(image_border(image_read("Molt5_CropLab_Ann.jpg"),"black","10x10"))
Img2 = rasterGrob(image_border(image_read("Molt50_CropLab_Ann.jpg"),"black","10x10"))
Img1 = rasterGrob(image_border(image_read("Molt95B_CropLab_Ann.jpg"),"black","10x10"))

# arrange the plot and the image side by side
png("Eseal Molt Fig 2_Oct2023.png",width=6,height=5,units="in",res=600)
grid.arrange(f1, Img1, Img2, Img3, layout_matrix=lay,widths=c(1,1,1,1))
dev.off()

# Figure 3 (all seals tenure, start, and end date) ----------------------------
dat$start=dat$best-(dat$slope/2)
dat$end=dat$best+(dat$slope/2)

dat=dat[order(dat$start),] #order by year so y1 y2 calculations below work. 
dat$i=1:nrow(dat)

dat_long = dat %>%
  pivot_longer(cols=c("arrival", "start","end","departure"),
               names_to = "phenology",
               values_to = "date")

fig2 = ggplot(dat_long, aes(date,i)) +
  geom_segment(aes(yend = i, x = arrival, xend = departure), size=0.05, data = dat,col="grey20") +
  geom_segment(aes(yend = i, x = start, xend = end), size=0.05, data = dat,col="grey80") +
  geom_point(aes(fill = phenology, shape = phenology),stroke=0,size=.8) +
  scale_fill_manual(values = fig2_palette) +
  scale_y_continuous("Seals", breaks = NULL,limits=c(1,nrow(dat)+230)) +
  scale_x_continuous("Date (day of year)", breaks=seq(60,max(dat$departure,na.rm=TRUE),by=20),
                     limits=c(60,max(dat$departure,na.rm=TRUE)))+
  scale_shape_manual(values = 21:24) +
  theme_classic() +
  theme(axis.text.y = element_blank(),
        axis.text.x = element_text(size=12, hjust = 0.5),
        axis.title=element_text(size=14),
        legend.position = "none")+
  annotate("text",
           x = c(150,160,170,180),
           y = nrow(dat)+40,angle=45,
           label = c("Arrival", "Molt Start","Molt End", "Departure"),
           color = fig2_palette,
           hjust = 0) 
fig2
ggsave("fig3main.png",height=6,width=6,dpi=600)

#top inset - molt duration and haulout duration
dur_long= dat %>% 
  rename("Molt"="slope","Haul-out"="tenure") %>%
  pivot_longer(cols=c("Molt", "Haul-out"),
               names_to = "Duration",
               values_to = "Values") 

fig2topleft=ggplot(dur_long,aes(x=Values,fill=factor(Duration,levels=c("Molt","Haul-out"))))+ 
  geom_density(color="black")+
  xlab("Duration")+ylab("Fraction of Seals")+
  scale_fill_manual(values=alpha(c("grey80","grey20"),.6))+
  scale_x_continuous(expand=c(0,0),limits=c(0,78))+
  scale_y_continuous(expand=c(0,0),limits=c(0,.29))+
  labs(fill="")+
  theme_few()+theme(legend.position = c(.7,.8),
                    legend.direction = "horizontal",
                    axis.title=element_text(size=14),
                    axis.text=element_text(size=12));fig2topleft
ggsave("fig3topleft.png",height=3.5,width=5,dpi=600)

#middle inset - arrival and departure
tenure_long= dat %>% 
  rename("Arrival"="arrival","Departure"="departure") %>%
  pivot_longer(cols=c("Arrival", "Departure"),
               names_to = "Timepoint",
               values_to = "Values") 

fig2bottomleft=ggplot(tenure_long,aes(x=Values,fill=factor(Timepoint,levels=c("Arrival","Departure"))))+ 
  geom_density(color="black")+
  xlab("Date (day of year)")+ylab("Fraction of Seals")+
  scale_fill_manual(values=alpha(c("#559B9D", "#123F5A"),.6))+
  scale_x_continuous(expand=c(0,0),limits=c(50,200),breaks=seq(75,175,25))+
  scale_y_continuous(expand=c(0,0),limits=c(0,.031))+
  labs(fill="")+
  theme_few()+theme(legend.position = c(.3,.85),
                    legend.direction = "horizontal",
                    axis.title=element_text(size=14),
                    axis.text=element_text(size=12));fig2bottomleft
ggsave("fig3bottomleft.png",height=3.5,width=5,dpi=600)

#inset - cumulative
xmin=50;xmax=200;n=100000
cumulative_long1=data.frame(num=seq(from=xmin,to=xmax,length.out=n),
                           arrival_quant=ecdf(dat$arrival)(seq(from=xmin,to=xmax,length.out=n)),
                           departure_quant=ecdf(dat$departure)(seq(from=xmin,to=xmax,length.out=n))) %>% 
  mutate(diff_quant=arrival_quant-departure_quant) %>% 
  rename("Cumulative Arrivals"="arrival_quant",
         "Present on Colony"="diff_quant",
         "Cumulative Departures"="departure_quant") %>% 
  pivot_longer(cols=c("Cumulative Arrivals","Present on Colony","Cumulative Departures"),
               names_to = "Timepoint",
               values_to = "Values")
  
fig2topright=ggplot(cumulative_long1,aes(x=num,y=Values,
                                  colour=factor(Timepoint),
                                  linetype=factor(Timepoint)))+ #add levels here if we need 
  #geom_line()+
  stat_smooth(method = "lm",formula = y ~ poly(x, 24), se = FALSE)+
  xlab("Date (day of year)")+ylab("Fraction of Seals")+
  scale_colour_manual(values=c("#559B9D","#123F5A","grey50"))+
  scale_linetype_manual(values=c(2,2,1))+
  scale_x_continuous(expand=c(0,0),limits=c(50,200),breaks=seq(75,175,25))+
  scale_y_continuous(breaks=seq(0,1,.25),labels=scales::percent)+
  labs(colour="",linetype="",linewidth="")+
  theme_few()+theme(legend.position = c(.25,.85),
                    axis.title=element_text(size=14),
                    axis.text=element_text(size=12),
                    legend.background = element_rect(fill='transparent',colour='transparent'),
                    legend.box.background = element_rect(fill='transparent',colour='transparent'));fig2topright
ggsave("fig3topright.png",height=3.5,width=5,dpi=600)

############ cumulative molt
# - cumulative molt
xmin=50;xmax=200;n=100000
cumulative_long2=data.frame(num=seq(from=xmin,to=xmax,length.out=n),
                           start_quant=ecdf(dat$start)(seq(from=xmin,to=xmax,length.out=n)),
                           end_quant=ecdf(dat$end)(seq(from=xmin,to=xmax,length.out=n))) %>% 
  mutate(diff_quant=start_quant-end_quant) %>% 
  rename("Cumulative Molt Start"="start_quant",
         "Molting"="diff_quant",
         "Cumulative Molt End"="end_quant") %>% 
  pivot_longer(cols=c("Cumulative Molt Start","Molting","Cumulative Molt End"),
               names_to = "Timepoint",
               values_to = "Values")

fig2bottomright=ggplot(cumulative_long2,aes(x=num,y=Values,
                                      colour=factor(Timepoint,levels=c("Cumulative Molt Start","Cumulative Molt End","Molting")),
                                      linetype=factor(Timepoint,levels=c("Cumulative Molt Start","Cumulative Molt End","Molting"))))+ #add levels here if we need 
  #geom_line()+
  stat_smooth(method = "lm",formula = y ~ poly(x, 24), se = FALSE)+
  xlab("Date (day of year)")+ylab("Fraction of Seals")+
  scale_colour_manual(values=c("#235D72","#A4DAC1","grey50"))+
  scale_linetype_manual(values=c(2,2,1))+
  scale_x_continuous(expand=c(0,0),limits=c(50,200),breaks=seq(75,175,25))+
  scale_y_continuous(breaks=seq(0,1,.25),labels=scales::percent)+
  labs(colour="",linetype="",linewidth="")+
  theme_few()+theme(legend.position = c(.25,.85),
                    axis.title=element_text(size=14),
                    axis.text=element_text(size=12),
                    legend.background = element_rect(fill='transparent',colour='transparent'),
                    legend.box.background = element_rect(fill='transparent',colour='transparent'));fig2bottomright
ggsave("fig3bottomright.png",height=3.5,width=5,dpi=600)

#combine figures
ggarrange(fig2,labels="A",
  ggarrange(fig2topleft,fig2topright,fig2bottomleft,fig2bottomright,nrow=2,ncol=2,labels=c("B","C","D","E")),
  nrow=2)+ bgcolor("white")+border("transparent")

ggsave("Eseal Molt Fig3_Oct2023.png", height = 11, width = 9,dpi=600)

# Figure 4 (violin plots ~ age sex repro) ----------------------------------------------------------------------------------------------

dat_long3 <- dat %>%
  pivot_longer(cols=c("slope", "start","tenure"),
               names_to = "Variable",
               values_to = "Value")

dat_long3$Variable = recode_factor(dat_long3$Variable, slope = "Molt Duration\n(days)", 
                                   start = "Molt Start Date\n(day of year)",
                                   tenure="Haul-out Duration\n(days)")

dat_long3$agesexcat=factor(dat_long3$agesexcat,levels=c("Skip Adult Female","Repro Adult Female", "Juvenile Male","Juvenile Female"))

labels=data.frame(
  label=LETTERS[1:3],
  Variable=levels(dat_long3$Variable),
  agesexcat="Skip Adult Female"
)

labels$Variable = recode_factor(labels$Variable, slope = "Molt Duration\n(days)", 
                                   start = "Molt Start Date\n(day of year)",
                                   tenure="Haul-out Duration\n(days)")

### Fig 4 models ------------------

#Calculate (adjusted) weight means per group & add letters to each mean
#ModelMoltDur=glm(slope~agesexcat,data=dat,family=Gamma);summary(ModelMoltDur)
ModelMoltDur=glmer(slope~agesexcat+(1|animalID),data=dat,family="Gamma"(link='log'));summary(ModelMoltDur)

#ModelMoltStart=glm(start~agesexcat,data=dat,family=Gamma);summary(ModelMoltStart)
ModelMoltStart=glmer(start~agesexcat+(1|animalID),data=dat,family="Gamma"(link='log'));summary(ModelMoltStart)

#ModelHauloutDur=glm(tenure~agesexcat,data=dat,family=Gamma);summary(ModelHauloutDur)
ModelHauloutDur=glmer(tenure~agesexcat+(1|animalID),data=dat,family="Gamma"(link='log'));summary(ModelHauloutDur)

ModelMoltDurCLD = cld(object = emmeans(object = ModelMoltDur,type="response",specs="agesexcat"),
                       Letters=letters,sort=FALSE,alpha = 0.05)
ModelMoltStartCLD = cld(object = emmeans(object = ModelMoltStart,type="response",specs="agesexcat"),
                      Letters=letters,sort=FALSE,alpha = 0.05)
ModelHauloutDurCLD = cld(object = emmeans(object = ModelHauloutDur,type="response",specs="agesexcat"),
                      Letters=letters,sort=FALSE,alpha = 0.05)

CLDall=data.frame(
  rbind(as.data.frame(ModelMoltDurCLD),as.data.frame(ModelMoltStartCLD),as.data.frame(ModelHauloutDurCLD)),
  Variable=rep(labels$Variable,each=4))

pt=ggplot(dat_long3,aes(y=Value,x=agesexcat,fill=agesexcat))+ #Molt Duration
  geom_violin(alpha=.3,aes(colour=agesexcat))+ylab("")+xlab("")+
  geom_point(aes(col=agesexcat),pch=21,bg=NA,size=1,stroke=.2,position=position_jitterdodge(jitter.width=1))+
  scale_fill_manual(values = figmain_palette) +
  scale_colour_manual(values = figmain_palette) +
  theme_few()+theme(legend.position="none",strip.placement = "outside")+
  scale_y_continuous(expand=c(0,5))+
  scale_x_discrete(labels=c("Skip\nAdultFemale","Repro\nAdultFemale","Juvenile\nMale","Juvenile\nFemale"))+
  geom_text(data=labels,x=0.5, y=c(32,180,110),aes(label=label))+
  geom_text(data = CLDall, aes(y = rep(c(32,180,110),each=4),x = agesexcat,label=str_trim(.group)),size=2.5)+
  facet_grid(Variable~.,scales="free",switch='y');pt

ggsave(filename="Eseal Molt Fig4_Feb2024.png",width=5,height=6)

# Figure 5 (haulout dur ~ arrival) -----------------------------------------

#not normal.... so use glm/Gamma 
f1=lm(tenure~arrival,data=subset(dat,agesexcat=="Repro Adult Female"))
shapiro.test(resid(f1))

### Fig 5 models ------------------------

#is there a relationship between duration and timing for each age class? 
#glm models for comparison
#summary(glm(tenure~arrival,family="Gamma",data=subset(dat,agesexcat=="Skip Adult Female")))
#summary(glm(tenure~arrival,family="Gamma",data=subset(dat,agesexcat=="Repro Adult Female")))
#summary(glm(tenure~arrival,family="Gamma",data=subset(dat,agesexcat=="Juvenile Female")))
#summary(glm(tenure~arrival,family="Gamma",data=subset(dat,agesexcat=="Juvenile Male")))

#glmer models actually used in manuscript
#divided predictor (arrival dates) to facilitate convergence. 
#model produces warnings about identifiability due to small random effects variance.  
SkipMod=glmer(tenure~I(arrival/100)+(1|animalID),family="Gamma"(link='log'),data=subset(dat,agesexcat=="Skip Adult Female"));summary(SkipMod)
ReproMod=glmer(tenure~I(arrival/100)+(1|animalID),family="Gamma"(link='log'),data=subset(dat,agesexcat=="Repro Adult Female"));summary(ReproMod)
JuvFemMod=glmer(tenure~I(arrival/100)+(1|animalID),family="Gamma"(link='log'),data=subset(dat,agesexcat=="Juvenile Female"));summary(JuvFemMod)
JuvMaleMod=glmer(tenure~I(arrival/100)+(1|animalID),family="Gamma"(link='log'),data=subset(dat,agesexcat=="Juvenile Male"));summary(JuvMaleMod)

#note that bootmer doesn't use animalID for calculation
newDat=data.frame(arrival=(seq(min(subset(dat,agesexcat=="Skip Adult Female")[,"arrival"],na.rm=TRUE),
                               max(subset(dat,agesexcat=="Skip Adult Female")[,"arrival"],na.rm=TRUE),by=1)),
                  animalID=1561)
newDatSkip=cbind(newDat,exp(predictInterval(SkipMod, newdata = newDat,
                                          n.sims = 999,type="linear.prediction",include.resid.var = FALSE)),
                 data.frame(agesexcat="Skip Adult Female"))
newDat=data.frame(arrival=(seq(min(subset(dat,agesexcat=="Repro Adult Female")[,"arrival"],na.rm=TRUE),
                        max(subset(dat,agesexcat=="Repro Adult Female")[,"arrival"],na.rm=TRUE),by=1)),
           animalID=1561)
newDatRepro=cbind(newDat,exp(predictInterval(ReproMod, newdata = newDat,
                                           n.sims = 999,type="linear.prediction",include.resid.var = FALSE)),
                  data.frame(agesexcat="Repro Adult Female"))
newDat=data.frame(arrival=(seq(min(subset(dat,agesexcat=="Juvenile Female")[,"arrival"],na.rm=TRUE),
                        max(subset(dat,agesexcat=="Juvenile Female")[,"arrival"],na.rm=TRUE),by=1)),
           animalID=1561)
newDatJuvFem=cbind(newDat,exp(predictInterval(JuvFemMod, newdata = newDat,
                                            n.sims = 999,type="linear.prediction",include.resid.var = FALSE)),
                   data.frame(agesexcat="Juvenile Female"))
newDat=data.frame(arrival=(seq(min(subset(dat,agesexcat=="Juvenile Male")[,"arrival"],na.rm=TRUE),
                               max(subset(dat,agesexcat=="Juvenile Male")[,"arrival"],na.rm=TRUE),by=1)),
                  animalID=1561)
newDatJuvMale=cbind(newDat,exp(predictInterval(JuvMaleMod, newdata = newDat,
                                             n.sims = 999,type="linear.prediction",include.resid.var = FALSE)),
                    data.frame(agesexcat="Juvenile Male"))
newDatAll=rbind(newDatSkip,newDatRepro,newDatJuvFem,newDatJuvMale)
colnames(newDatAll)[3]="tenure"

newDatAll$agesexcat=factor(newDatAll$agesexcat,levels=c("Skip Adult Female","Repro Adult Female", "Juvenile Male","Juvenile Female"))

# Determine p-values of regression
p.vals = lapply(unique(dat$agesexcat), function(i) {
  data.frame(agesexcat=i,p.val=
               coef(summary(glmer(tenure ~ arrival+(1|animalID), data=dat[dat$agesexcat==i, ],family="Gamma")))[2,4])
})
p.vals = do.call(rbind, p.vals) # Turn pvals into a data frame
p.vals = p.vals[p.vals$p.val < 0.05, ] # Keep only rows with p.val < 0.05
#all are significant

dat$agesexcat=factor(dat$agesexcat,levels=c("Skip Adult Female","Repro Adult Female", "Juvenile Male","Juvenile Female"))

labels=data.frame(
  label=c("A","B","C","D"),
  agesexcat=factor(levels(dat$agesexcat),levels=levels(dat$agesexcat))
)

fig4= ggplot(dat,aes(x=arrival,y=tenure,fill=agesexcat)) + 
  geom_ribbon(data=newDatAll,aes(x=arrival,ymin=lwr,ymax=upr,fill=agesexcat),
              alpha=0.5,linetype=0)+
  geom_line(data=newDatAll,aes(x=arrival,y=tenure,color=agesexcat))+
  geom_point(aes(fill = factor(agesexcat),alpha=.5),pch=21,color="black",stroke=.5,size=1.4)+
  facet_grid(cols=vars(agesexcat),scales="free",switch="y")+
  scale_colour_manual(values=figmain_palette)+
  xlab("Haulout Arrival (day of year)")+ylab("Haul-out Duration (days)")+
  theme_few()+theme(legend.position="none",strip.placement = "outside",
                    panel.spacing.x = unit(4, "mm"))+

  geom_text(data=labels,y=90, x=c(75,80,75,70),aes(label=label))+
  scale_x_continuous(limits=c(60,160),breaks=seq(75,150,by=25))+
  scale_fill_manual(values=figmain_palette);fig4
ggsave(filename="Eseal Molt Fig5_Feb2024.png",width=7,height=3)

# Figure 6 (circular fig) --------------------------------------

setwd("C:/Users/roxan/Documents/Publications/Submitted/ROXANNE_Molt/Eseal Molt Final Data")
dat2=read.csv("MoltMSFinalCircular.csv")
dat2$Season=factor(dat2$Season,levels=unique(dat2$Season))

cols=viridis_pal()(8)
cols[8]="goldenrod"

df2 = data.frame(x = as.Date(dat2$Q50), y = 8, Season = factor(dat2$Season,levels=unique(dat2$Season)),
                 text2=c("Pre-Breeding Arrival","Birth","Wean","Post-Breeding Departure","Pre-Molt Arrival",
                         "Molt Start","Molt End","Post-Molt Departure"),
                 rot=julian(as.Date(dat2$Q50),origin=as.Date("1900-01-01"))*(360/365))

p1=ggplot(dat2, aes(y=8,yend=8,group=Season,fill=Season,colour=Season)) +
  geom_segment(aes(x=as.Date("1900-01-01"),
                   xend=as.Date("1900-12-31")),col="black",size=1) +
  geom_point(aes(x=as.Date(Q50)),size=5,pch=21,col="black",stroke=1.2) +
  scale_y_discrete(expand = c(0, 1), breaks = NULL) +
  scale_x_date(date_breaks = "1 month", date_labels = month.abb,
               limits = as.Date(c("1900-01-01","1900-12-31"))) +
  geom_textpath(aes(x=as.Date("1900-02-05"),y=7.8,size=1.2,label="Lactation"),col="black",fontface="bold") +
  geom_textpath(aes(x=as.Date("1900-04-01"),y=7.6,size=1.2,label="Short\nTrip"),col="black",fontface="bold") +
  geom_textpath(aes(x=as.Date("1900-05-15"),y=7.7,size=1.2,label="Molt"),col="black",fontface="bold") +
  geom_textpath(aes(x=as.Date("1900-10-01"),y=7.6,size=1.2,label="Long\nTrip"),col="black",fontface="bold") +
  geom_text(data=df2,aes(x=x+c(0,5,-3,+3,0,-3,0,0),y=y+0.15,label=text2,
                         angle=90-rot,colour=Season),
            hjust=0,size=4) +
  coord_curvedpolar(clip="off") +
  scale_fill_manual(values=cols)+
  scale_colour_manual(values=cols)+
  theme_bw() + xlab(NULL) + ylab(NULL)+
  theme(axis.text.x = element_text(size=12,vjust=-.5),
        plot.title=element_text(size=20),
        legend.position = "NULL",
        panel.border = element_blank(),
        panel.grid.minor = element_blank(),
        panel.grid.major.x=element_line(colour="grey98"))+
  ggtitle("A) Average Annual Cycle");p1

new=read_excel("MoltMSFinalCircularSD.xlsx",n_max=8)
new$Season=factor(new$season,levels=unique(new$season))
datnew=new[c(1,2,4:8),]
p2=ggplot(datnew, aes(x=Season,group=Season,fill=Season))+
  geom_bar(aes(x=Season, y=SD), stat="identity", col="black",width=0.6)+
  scale_fill_manual(values=cols[c(1,2,4:8)])+
  geom_text(aes(x=Season,y=SD+.5,label=SD),size=5)+
  scale_y_continuous(expand=expansion(mult = c(0, .1)))+
  scale_x_discrete(labels=str_wrap(c("Pre-Breeding Arrival","Birth","Post-Breeding Departure","Pre-Molt Arrival",
                                     "Molt Start","Molt End","Post-Molt Departure"),4))+
  theme_few() + xlab(NULL) + ylab("Standard Deviation (Days)")+ 
  theme(legend.position = 'NULL',axis.text.x = element_text(size=12),
        plot.title=element_text(size=20),
        axis.text.y = element_text(size=12))+
  ggtitle("B) Standard Deviation Annual Cycle");p2

ggarrange(p1,"NULL",p2,
          nrow=3,heights = c(1.6,.05,1))
setwd("C:/Users/roxan/Documents/Publications/Submitted/ROXANNE_Molt/Eseal Molt Figures")
ggsave("Molt Fig6_Feb2024.png",height=12,width=8,bg="white")

#Supplemental Figure 1 (age effects) ------------------------------------

fig5= ggplot(dat_long3,aes(x=jitter(age),y=Value,col=agesexcat)) + 
  geom_point(aes(col = agesexcat),alpha=.3)+
  scale_colour_manual(values=figmain_palette)+
  geom_smooth(data = dat_long3, aes(x=age,y=Value,group=agesexcat,colour= agesexcat,fill=agesexcat),
              alpha=.2,method = "glm", method.args=list(family="Gamma"))+
  facet_grid(vars(Variable),scales="free",switch='y')+
  xlab("Age (years)")+ylab("")+labs(col="",fill="")+
  theme_few()+theme(legend.position="right",strip.placement = "outside",axis.title.y=element_text(size=14))+
  scale_fill_manual(values=figmain_palette);fig5
ggsave(filename="Eseal Molt SuppFig1_Oct2023.png",width=10,height=7)

# Supplemental Figure 2 (by year) ------------------------------------

tenure_long = tenure_long %>% 
  separate(X, c('Year', 'animalID')) 

FigS2A=ggplot(tenure_long,aes(x=Values,fill=factor(Timepoint,levels=c("Arrival","Departure"))))+ 
  geom_density(color="black")+
  xlab("Date (day of year)")+ylab("Fraction of Seals")+
  facet_wrap(.~Year,ncol=1)+
  scale_fill_manual(values=alpha(c("#559B9D", "#123F5A"),.6))+
  scale_x_continuous(expand=c(0,0),limits=c(50,200),breaks=seq(75,175,25))+
  scale_y_continuous(expand=c(0,0),limits=c(0,.055))+
  labs(fill="")+
  theme_few()+theme(legend.position = "top",
                    legend.direction="vertical",
                    axis.title=element_text(size=14),
                    axis.text=element_text(size=12));FigS2A

xmin=50;xmax=200;n=100000
Years=unique(dat$Year)

for(i in 1:length(Years)){
  cumulative_long1=data.frame(Year=Years[i],
                              num=seq(from=xmin,to=xmax,length.out=n),
                              arrival_quant=ecdf(dat$arrival[dat$Year==Years[i]])(seq(from=xmin,to=xmax,length.out=n)),
                              departure_quant=ecdf(dat$departure[dat$Year==Years[i]])(seq(from=xmin,to=xmax,length.out=n))) %>% 
    mutate(diff_quant=arrival_quant-departure_quant) %>% 
    rename("Cumulative Arrivals"="arrival_quant",
           "Present on Colony"="diff_quant",
           "Cumulative Departures"="departure_quant") %>% 
    pivot_longer(cols=c("Cumulative Arrivals","Present on Colony","Cumulative Departures"),
                 names_to = "Timepoint",
                 values_to = "Values")
  if(i==1){
    cumulative_long1_all=cumulative_long1
  }else{
    cumulative_long1_all=rbind(cumulative_long1_all,cumulative_long1)
  }
}

FigS2B=ggplot(cumulative_long1_all,aes(x=num,y=Values,
                                       colour=factor(Timepoint),
                                       linetype=factor(Timepoint)))+ 
  stat_smooth(method = "lm",formula = y ~ poly(x, 24), se = FALSE)+
  xlab("Date (day of year)")+ylab("Fraction of Seals")+
  facet_wrap(.~Year,ncol=1)+
  scale_colour_manual(values=c("#559B9D","#123F5A","grey50"))+
  scale_linetype_manual(values=c(2,2,1))+
  scale_x_continuous(expand=c(0,0),limits=c(50,200),breaks=seq(75,175,25))+
  scale_y_continuous(breaks=seq(0,1,.25),labels=scales::percent)+
  labs(colour="",linetype="",linewidth="")+
  theme_few()+theme(legend.position = "top",
                    legend.direction="vertical",
                    axis.title=element_text(size=14),
                    axis.text=element_text(size=12),
                    legend.background = element_rect(fill='transparent',colour='transparent'),
                    legend.box.background = element_rect(fill='transparent',colour='transparent'));FigS2B

# - cumulative molt
xmin=50;xmax=200;n=100000

for(i in 1:length(Years)){
  cumulative_long2=data.frame(Year=Years[i],
                              num=seq(from=xmin,to=xmax,length.out=n),
                              start_quant=ecdf(dat$start[dat$Year==Years[i]])(seq(from=xmin,to=xmax,length.out=n)),
                              end_quant=ecdf(dat$end[dat$Year==Years[i]])(seq(from=xmin,to=xmax,length.out=n))) %>% 
    mutate(diff_quant=start_quant-end_quant) %>% 
    rename("Cumulative Molt Start"="start_quant",
           "Molting"="diff_quant",
           "Cumulative Molt End"="end_quant") %>% 
    pivot_longer(cols=c("Cumulative Molt Start","Molting","Cumulative Molt End"),
                 names_to = "Timepoint",
                 values_to = "Values")
  if(i==1){
    cumulative_long2_all=cumulative_long2
  }else{
    cumulative_long2_all=rbind(cumulative_long2_all,cumulative_long2)
  }
}

FigS2C=ggplot(cumulative_long2_all,aes(x=num,y=Values,
                                       colour=factor(Timepoint,levels=c("Cumulative Molt Start","Cumulative Molt End","Molting")),
                                       linetype=factor(Timepoint,levels=c("Cumulative Molt Start","Cumulative Molt End","Molting"))))+ #add levels here if we need 
  stat_smooth(method = "lm",formula = y ~ poly(x, 24), se = FALSE)+
  xlab("Date (day of year)")+ylab("Fraction of Seals")+
  facet_wrap(.~Year,ncol=1)+
  scale_colour_manual(values=c("#235D72","#A4DAC1","grey50"))+
  scale_linetype_manual(values=c(2,2,1))+
  scale_x_continuous(expand=c(0,0),limits=c(50,200),breaks=seq(75,175,25))+
  scale_y_continuous(breaks=seq(0,1,.25),labels=scales::percent)+
  labs(colour="",linetype="",linewidth="")+
  theme_few()+theme(legend.position = "top",
                    legend.direction="vertical",
                    axis.title=element_text(size=14),
                    axis.text=element_text(size=12),
                    legend.background = element_rect(fill='transparent',colour='transparent'),
                    legend.box.background = element_rect(fill='transparent',colour='transparent'));FigS2C

ggarrange(plotlist=list(FigS2A,FigS2B,FigS2C),
          ncol = 3,
          labels=c("a","b","c"))
ggsave("Eseal Molt SuppFig2_Feb2024.png",height=9,width=8)

# Descriptive calcs --------------------------------------------------------

#latency between arrival-start and end-departure
dat %>% 
  mutate(diff=start-arrival) %>% 
  summarize(mean=mean(diff,na.rm=T),
            sd=sd(diff,na.rm=T),
            n=length(diff),
            se=sd/sqrt(n))

dat %>% 
  mutate(diff=departure-end) %>% 
  summarize(mean=mean(diff,na.rm=T),
            sd=sd(diff,na.rm=T),
            n=length(diff),
            se=sd/sqrt(n))

## Within vs between group variation -------------------------------------
# GLMER with year - start date
StartMixedYear=glmer(start~agesexcat*Year+(1|animalID),family="Gamma"(link='log'),data=dat);summary(StartMixedYear)
dat$PredictMixedYear=predict(StartMixedYear,re.form=NA,type="response") #pull out fixed effects only
dat$residGroupsYear=dat$PredictMixedYear-mean(dat$start)
1-var(dat$residGroupsYear)/var(dat$start) #var explained by age-sex cat
#75.8% of variation in molt start date is explained by individual (after accounting for years and variation among years). 

# GLMER with year - molt duration (added custom optimizer to facilitate convergence)
DurMixedYear=glmer(slope~agesexcat*Year+(1|animalID),family="Gamma"(link='log'),data=dat,
                   control=glmerControl(optimizer="bobyqa",optCtrl = list(maxfun = 100000)));summary(DurMixedYear)
dat$PredictDurMixedYear=predict(DurMixedYear,re.form=NA,type="response") #pull out fixed effects only
dat$residGroupsDurYear=dat$PredictDurMixedYear-mean(dat$slope)
1-var(dat$residGroupsDurYear)/var(dat$slope) #var explained by age-sex cat
#76.6% of variation in molt duration is explained by individual (after accounting for years and variation among years). 

# GLMER with year - haul-out duration
TenMixedYear=glmer(tenure~agesexcat*Year+(1|animalID),family="Gamma"(link='log'),data=dat);summary(TenMixedYear)
dat$PredictTenMixedYear=NA #some molt haulout durations are NA so need to add an extra step
dat[!is.na(dat$tenure),"PredictTenMixedYear"]=predict(TenMixedYear,re.form=NA,type="response") #pull out fixed effects only
dat$residGroupsTenYear=dat$PredictTenMixedYear-mean(dat$tenure,na.rm=TRUE)
1-var(dat$residGroupsTenYear,na.rm=TRUE)/var(dat$tenure,na.rm=TRUE) #var explained by age-sex cat
#79.8 % of variation in haulout duration is explained by individual (after accounting for years and variation among years). 

## Checking for individual effects ----------------------------------------
dat %>% 
  group_by(animalID) %>% 
  summarize(n=length(animalID)) %>% 
  arrange(-n) %>% 
  group_by(n) %>% 
  summarize(count=length(n))

dat3=dat %>% 
  group_by(animalID) %>% 
  summarize(n=length(animalID)) %>% 
  arrange(-n) %>% 
  subset(n>5)

dat %>% 
  group_by(Year) %>% 
  summarize(mean=mean(best))

## Calculate molt cycles per year -----------------
# #calculating mean and range 
dat %>% 
  group_by(Year) %>% 
  summarize(num=length(Year)) #%>% #comment this pipe out to see yearly numbers
  summarize(mean(num,na.rm=TRUE))

